/*
 * Copyright (C) 2006 TopCoder Inc., All Rights Reserved.
 */
package com.topcoder.testframework;

import java.util.HashMap;
import java.util.Map;

import org.apache.tools.ant.BuildException;

import junit.framework.TestCase;
import junit.framework.TestSuite;
import junit.framework.Test;

/**
 * <p>
 * Unit test cases for CredentialProperty.
 * </p>
 *
 * @author TCSDEVELOPER
 * @version 1.0
 */
public class CredentialPropertyTests extends TestCase {
    /**
     * <p>
     * Map instance used to constructing CredentialProperty instance.
     * </p>
     */
    private Map propertyMap = new HashMap();

    /**
     * <p>
     * CredentialProperty instance for testing.
     * </p>
     */
    private CredentialProperty property;

    /**
     * <p>
     * Setup test environment.
     * </p>
     *
     */
    protected void setUp() {
        propertyMap = new HashMap();
        property = new CredentialProperty(Server.USER_NAME, propertyMap);
    }

    /**
     * <p>
     * Tears down test environment.
     * </p>
     *
     */
    protected void tearDown() {
        propertyMap = null;
        property = null;
    }

    /**
     * <p>
     * Return all tests.
     * </p>
     *
     * @return all tests
     */
    public static Test suite() {
        return new TestSuite(CredentialPropertyTests.class);
    }

    /**
     * <p>
     * Tests ctor CredentialProperty#CredentialProperty(String,Map) for accuracy.
     * Expects a new CredentialProperty instance created successfully.
     * </p>
     */
    public void testCtor() {
        assertNotNull("Failed to create new CredentialProperty instance.", property);
    }

    /**
     * <p>
     * Tests ctor CredentialProperty#CredentialProperty(String,Map) for failure.
     * It tests the case that when name is null and expects IllegalArgumentException.
     * </p>
     */
    public void testCtor_NullName() {
        try {
            new CredentialProperty(null, new HashMap());
            fail("IllegalArgumentException expected.");
        } catch (IllegalArgumentException iae) {
            //good
        }
    }

    /**
     * <p>
     * Tests ctor CredentialProperty#CredentialProperty(String,Map) for failure.
     * It tests the case that when name is empty and expects IllegalArgumentException.
     * </p>
     */
    public void testCtor_EmptyName() {
        try {
            new CredentialProperty(" ", new HashMap());
            fail("IllegalArgumentException expected.");
        } catch (IllegalArgumentException iae) {
            //good
        }
    }

    /**
     * <p>
     * Tests ctor CredentialProperty#CredentialProperty(String,Map) for failure.
     * It tests the case that when propertyMap is null and expects IllegalArgumentException.
     * </p>
     */
    public void testCtor_NullPropertyMap() {
        try {
            new CredentialProperty(Server.USER_NAME, null);
            fail("IllegalArgumentException expected.");
        } catch (IllegalArgumentException iae) {
            //good
        }
    }

    /**
     * <p>
     * Tests CredentialProperty#setValue(String) for accuracy.
     * Expects value is correctly set to the user_name key.
     * </p>
     */
    public void testSetValue() {
        property.setValue("topcoder");

        assertEquals("Failed to get correct use_name value.", "topcoder", propertyMap.get(Server.USER_NAME));
    }

    /**
     * <p>
     * Tests CredentialProperty#setValue(String) for failure.
     * It tests the case that when user_name value is set twice and expects BuildException.
     * </p>
     */
    public void testSetValue_DumplicateKey() {
        try {
            property.setValue("topcoder");

            CredentialProperty property2 = new CredentialProperty(Server.USER_NAME, propertyMap);
            property2.setValue("topcoder");

            fail("BuildException expected.");
        } catch (BuildException be) {
            //good
        }
    }

    /**
     * <p>
     * Tests CredentialProperty#setValue(String) for failure.
     * It tests the case that when value is empty and expects success.
     * </p>
     */
    public void testSetValue_EmptyValue() {
        property.setValue("");
    }

}