/*
 * Copyright (C) 2006 TopCoder Inc., All Rights Reserved.
 */
package com.topcoder.testframework;

import java.io.File;

import junit.framework.TestCase;
import junit.framework.TestSuite;
import junit.framework.Test;

/**
 * <p>
 * Unit test cases for DataServer.
 * </p>
 *
 * @author TCSDEVELOPER
 * @version 1.0
 */
public class DataServerTests extends TestCase {
    /**
     * Type constant used for constructing DataServer instance.
     */
    private static final String TYPE = "postgres";

    /**
     * <p>
     * DataServer instance for testing.
     * </p>
     */
    private DataServer server;

    /**
     * <p>
     * Setup test environment.
     * </p>
     *
     */
    protected void setUp() {
        server = new DummyDataServer(TYPE);
    }

    /**
     * <p>
     * Tears down test environment.
     * </p>
     *
     */
    protected void tearDown() {
        server = null;
    }

    /**
     * <p>
     * Return all tests.
     * </p>
     *
     * @return all tests
     */
    public static Test suite() {
        return new TestSuite(DataServerTests.class);
    }

    /**
     * <p>
     * Tests ctor DataServer#DataServer(String) for accuracy.
     * Expects a new DataServer instance created successfully.
     * </p>
     */
    public void testCtor() {
        assertNotNull("Failed to create new DataServer instance.", new DummyDataServer(TYPE));
    }

    /**
     * <p>
     * Tests ctor DataServer#DataServer(String) for failure.
     * It tests the case that when type is null and expects IllegalArgumentException.
     * </p>
     */
    public void testCtor_NullType() {
        try {
            new DummyDataServer(null);
            fail("IllegalArgumentException expected.");
        } catch (IllegalArgumentException iae) {
            //good
        }
    }

    /**
     * <p>
     * Tests ctor DataServer#DataServer(String) for failure.
     * It tests the case that when type is empty and expects IllegalArgumentException.
     * </p>
     */
    public void testCtor1_EmptyType() {
        try {
            new DummyDataServer(" ");
            fail("IllegalArgumentException expected.");
        } catch (IllegalArgumentException iae) {
            //good
        }
    }

    /**
     * <p>
     * Tests DataServer#getJarFile() for accuracy.
     * Expects the jar file is initially null.
     * </p>
     */
    public void testGetJarFile() {
        assertNull("Expects null jar file.", server.getJarFile());
    }

    /**
     * <p>
     * Tests DataServer#setJarFile(File) for accuracy.
     * Expects the jar file is correctly set.
     * </p>
     */
    public void testSetJarFile() {
        File jarFile = new File("test_files/sample.jar");
        server.setJarFile(jarFile);

        assertEquals("Failed to get correct jar file name.", "sample.jar", server.getJarFile().getName());
    }

    /**
     * <p>
     * This class extends DataServer class.
     * It is used for testing propose.
     * </p>
     *
     * @author TCSDEVELOPER
     * @version 1.0
     */
    public static class DummyDataServer extends DataServer {

        /**
         * <p>
         * Constructs a new DummyDataServer instance.
         * </p>
         *
         * @param type the type of the server
         * @throws IllegalArgumentException if type is null or empty
         */
        protected DummyDataServer(String type) {
            super(type);
        }

        /**
         * <p>
         * Not implemented.
         * </p>
         */
        public void startUp() {
            // do nothing, testing only.
        }

        /**
         * <p>
         * Not implemented.
         * </p>
         */
        public void shutDown() {
            // do nothing, testing only.
        }

        /**
         * <p>
         * Not implemented.
         * </p>
         */
        public void initData() {
            // do nothing, testing only.
        }

        /**
         * <p>
         * Not implemented.
         * </p>
         */
        public void cleanUpData() {
            // do nothing, testing only.
        }
    }

}