/*
 * Copyright (C) 2006 TopCoder Inc., All Rights Reserved.
 */
package com.topcoder.testframework;

import org.apache.tools.ant.BuildException;

import com.topcoder.testframework.web.DefaultWebApplicationServer;

import junit.framework.TestCase;
import junit.framework.TestSuite;
import junit.framework.Test;

/**
 * <p>
 * Unit test cases for ServerElement.
 * </p>
 *
 * @author TCSDEVELOPER
 * @version 1.0
 */

public class ServerElementTests extends TestCase {
    /**
     * <p>
     * The class name of default server implementation.
     * </p>
     */
    private static final String SERVER_CLASS = "com.topcoder.testframework.web.DefaultWebApplicationServer";

    /**
     * <p>
     * ServerElement instance for testing.
     * </p>
     */
    private ServerElement serverElement;

    /**
     * <p>
     * Setup test environment.
     * </p>
     *
     */
    protected void setUp() {
        serverElement = new ServerElement(SERVER_CLASS);
    }

    /**
     * <p>
     * Tears down test environment.
     * </p>
     *
     */
    protected void tearDown() {
        serverElement = null;
    }

    /**
     * <p>
     * Return all tests.
     * </p>
     *
     * @return all tests
     */
    public static Test suite() {
        return new TestSuite(ServerElementTests.class);
    }

    /**
     * <p>
     * Tests ctor ServerElement#ServerElement() for accuracy.
     * Expects a new ServerElement instance created successfully.
     * </p>
     */
    public void testCtor() {
        assertNotNull("Failed to create new ServerElement instance.", serverElement);
    }

    /**
     * <p>
     * Tests ServerElement#setAntTaskInfo(AntTaskInfo) for accuracy.
     * Expects equal AntTaskInfo instance.
     * </p>
     *
     * @throws Exception to JUnit
     */
    public void testSetAntTaskInfo() throws Exception {
        AntTaskInfo antTaskInfo = TestHelper.getAntTaskInfo();
        serverElement.setAntTaskInfo(antTaskInfo);

        assertEquals("Failed to get correct project name.", "OurProject",
                serverElement.getAntTaskInfo().getProject().getName());

        assertEquals("Failed to get correct task name.", "javac", serverElement.getAntTaskInfo().getTaskName());

        assertEquals("Failed to get correct file name.", TestHelper.SAMPLE_BUILD_XML,
                serverElement.getAntTaskInfo().getLocation().getFileName());

        assertEquals("Failed to get correct target name.", "compile",
                serverElement.getAntTaskInfo().getTarget().getName());
    }

    /**
     * <p>
     * Tests ServerElement#setAntTaskInfo(AntTaskInfo) for failure.
     * It tests the case that when antTaskInfo is null and expects IllegalArgumentException.
     * </p>
     */
    public void testSetAntTaskInfo_NullAntTaskInfo() {
        try {
            serverElement.setAntTaskInfo(null);
            fail("IllegalArgumentException expected.");
        } catch (IllegalArgumentException iae) {
            //good
        }
    }

    /**
     * <p>
     * Tests ServerElement#getAntTaskInfo() for accuracy.
     * Expects antTaskInfo is initially null.
     * </p>
     */
    public void testGetAntTaskInfo() {
        assertNull("Expects null antTaskInfo.", serverElement.getAntTaskInfo());
    }

    /**
     * <p>
     * Tests ServerElement#createDynamicElement(String) for accuracy.
     * Expects a new Server instance created successfully.
     * </p>
     *
     * @throws Exception to JUnit
     */
    public void testCreateDynamicElement() throws Exception {
        serverElement.setAntTaskInfo(TestHelper.getAntTaskInfo());

        Object obj = serverElement.createDynamicElement("tomcat5x");

        assertNotNull("Expects not null DefaultWebApplicationServer object.", obj);
        assertTrue("Expects the created object be type of DefaultWebApplicationServer.",
                obj instanceof DefaultWebApplicationServer);
        assertNotNull("Expects not null server instance in serverElement.", serverElement.getServer());
    }

    /**
     * <p>
     * Tests ServerElement#createDynamicElement(String) for failure.
     * It tests the case when an unknown serve occurs and expects BuildExcepiton.
     * </p>
     *
     * @throws Exception to JUnit
     */
    public void testCreateDynamicElement_UnKnownServer() throws Exception {
        serverElement.setAntTaskInfo(TestHelper.getAntTaskInfo());

        try {
            serverElement.createDynamicElement("topcoderServer");
            fail("BuildException expected.");
        } catch (BuildException be) {
            // good
        }
    }

    /**
     * <p>
     * Tests ServerElement#createDynamicElement(String) for failure.
     * It tests the case when AntTaskInfo isn't set before calling createDynamicElement() and expects BuildExcepiton.
     * </p>
     *
     * @throws Exception to JUnit
     */
    public void testCreateDynamicElement_NullAntTaskInfo() throws Exception {
        try {
            serverElement.createDynamicElement("tomcat5x");
            fail("BuildException expected.");
        } catch (BuildException be) {
            // good
        }
    }

    /**
     * <p>
     * Tests ServerElement#createDynamicElement(String) for failure.
     * It tests the case that when name is null and expects IllegalArgumentException.
     * </p>
     */
    public void testCreateDynamicElement_NullName() {
        try {
            serverElement.createDynamicElement(null);
            fail("IllegalArgumentException expected.");
        } catch (IllegalArgumentException iae) {
            //good
        }
    }

    /**
     * <p>
     * Tests ServerElement#createDynamicElement(String) for failure.
     * It tests the case that when name is empty and expects IllegalArgumentException.
     * </p>
     */
    public void testCreateDynamicElement_EmptyName() {
        try {
            serverElement.createDynamicElement(" ");
            fail("IllegalArgumentException expected.");
        } catch (IllegalArgumentException iae) {
            //good
        }
    }

    /**
     * <p>
     * Tests ServerElement#getServer() for accuracy.
     * Expects server is initially null.
     * </p>
     */
    public void testGetServer() {
        assertNull("Expects null server", serverElement.getServer());
    }
}