/*
 * Copyright (C) 2006 TopCoder Inc., All Rights Reserved.
 */
package com.topcoder.testframework.demo;

import java.io.IOException;

import javax.servlet.Filter;
import javax.servlet.FilterChain;
import javax.servlet.FilterConfig;
import javax.servlet.RequestDispatcher;
import javax.servlet.ServletException;
import javax.servlet.ServletRequest;
import javax.servlet.ServletResponse;

/**
 * <p>
 * This class implements Filter interface and it is used for demo purpose.
 * </p>
 *
 * <p>
 * The test case for this filter implementation is TestSimpleFilter, it is based on the Testing Framework
 * component and demonstrates how to write test case under Testing Framework component.
 * </p>
 *
 * @author TCSDEVELOPER
 * @version 1.0
 */
public class SimpleFilter implements Filter {

    /**
     * <p>
     * This method implements Filter#init(FilterConfig) and in current implementation, it does nothing.
     * </p>
     *
     * @param filterConfig the FilterConfig instance
     *
     * @throws ServletException when initialization fails.
     */
    public void init(FilterConfig filterConfig) throws ServletException {
        // ignore
    }

    /**
     * <p>
     * This method implements Filter#doFilter(ServletRequest,ServletResponse,FilterChain) method.
     * </p>
     *
     * <p>
     * It checks the site parameter in request, if its value equals to topcoder, then forward to success
     * html page, otherwise, forward to error html page.
     * </p>
     *
     * @param request The HttpRequest instance.
     * @param response The HttpResponse instance.
     * @param filterChain The FilterChain instance.
     *
     * @throws IOException when any exception which is due to input/output problems occurs.
     * @throws ServletException when the request cannot be handled.
     */
    public void doFilter(ServletRequest request, ServletResponse response, FilterChain filterChain)
        throws IOException, ServletException {
        String value = request.getParameter("site");
        if (!"topcoder".equalsIgnoreCase(value)) {
            // if the site value is not equal to topcoder, then forward to error.html page
            RequestDispatcher dispatcher = request.getRequestDispatcher("/error.html");
            dispatcher.forward(request, response);
        } else {
            // if the site value is equal to topcoder, then forward to success.html page
            RequestDispatcher dispatcher = request.getRequestDispatcher("/success.html");
            dispatcher.forward(request, response);
        }
    }

    /**
     * <p>
     * This method implements Filter#destroy() and in current implementation, it does nothing.
     * </p>
     *
     */
    public void destroy() {
        // ignore
    }

}
